#!/bin/sh
echo 'name: blaze-html
version: 0.6.1.1
id: blaze-html-0.6.1.1-d9a2e0519a92c20d0751dbc779791ce7

license: BSD3
copyright:
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
stability: Experimental
homepage: http://jaspervdj.be/blaze
package-url:
synopsis: A blazingly fast HTML combinator library for Haskell
description: A blazingly fast HTML combinator library for the Haskell
             programming language. The Text.Blaze module is a good
             starting point, as well as this tutorial:
             <http://jaspervdj.be/blaze/tutorial.html>.
category: Text
author: Jasper Van der Jeugt, Simon Meier
pkgpath: textproc/hs-blaze-html
exposed: True
exposed-modules: Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
                 Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
                 Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
                 Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
                 Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
                 Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
                 Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
                 Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
                 Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
                 Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
                 Text.Blaze.XHtml5.Attributes
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/blaze-html-0.6.1.1
library-dirs: /usr/local/lib/ghc/blaze-html-0.6.1.1
hs-libraries: HSblaze-html-0.6.1.1
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-185478ee9bcc4ae00bc1dbe06bac6937
         blaze-builder-0.3.1.1-ac49b512143342e2370aead8ef93c70b
         blaze-markup-0.5.1.5-2469a9388e0fb2943fc206e9c09e2bea
         bytestring-0.10.0.2-fdb789c5db2e1ca48eb014403eee81b4
         text-0.11.3.1-3fa3b4cb4ca4c0f49eeebe965c439ff9
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-blaze-html-0.6.1.1/html/blaze-html.haddock
haddock-html: /usr/local/share/doc/hs-blaze-html-0.6.1.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
